==> haskell-src-exts-util-0.2.5-391-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-src-exts-util.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-src-exts-util
version:              0.2.5
visibility:           public
id:                   haskell-src-exts-util-0.2.5-71fbdGl24kgGXj3bXHc9GW
key:                  haskell-src-exts-util-0.2.5-71fbdGl24kgGXj3bXHc9GW
license:              BSD-3-Clause
copyright:            All Rights Reserved
maintainer:           pepeiborra@gmail.com
author:               Neil Mitchell, Jose Iborra
homepage:             https://github.com/pepeiborra/haskell-src-exts-util
synopsis:             Helper functions for working with haskell-src-exts trees
description:          Helper functions for working with haskell-src-exts trees.
category:             language
abi:                  d926ae1d096fc400521d3458a46af0f4
exposed:              True
exposed-modules:      Language.Haskell.Exts.Util
hidden-modules:
    Language.Haskell.Exts.Bracket Language.Haskell.Exts.FreeVars
    Language.Haskell.Exts.Util.Internal Paths_haskell_src_exts_util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/haskell-src-exts-util-0.2.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/haskell-src-exts-util-0.2.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/haskell-src-exts-util-0.2.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-src-exts-util
hs-libraries:         HShaskell-src-exts-util-0.2.5-71fbdGl24kgGXj3bXHc9GW
depends:
    base-4.17.2.1 containers-0.6.7
    data-default-0.7.1.2-8yRIq8kwMNHG7OFJsT5Ayy
    haskell-src-exts-1.23.1-5HqAAAz38YeFTpnLlGS9cD transformers-0.5.6.2
    uniplate-1.6.13-D0FT4vP15xHCY9L33gQ2nB

haddock-interfaces:
    /usr/share/doc/haskell-src-exts-util/html/haskell-src-exts-util.haddock

haddock-html:         /usr/share/doc/haskell-src-exts-util/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-src-exts-util-0.2.5-392-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-src-exts-util.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-src-exts-util
version:              0.2.5
visibility:           public
id:                   haskell-src-exts-util-0.2.5-52dyUv2dnwdFl4IOXeEnw9
key:                  haskell-src-exts-util-0.2.5-52dyUv2dnwdFl4IOXeEnw9
license:              BSD-3-Clause
copyright:            All Rights Reserved
maintainer:           pepeiborra@gmail.com
author:               Neil Mitchell, Jose Iborra
homepage:             https://github.com/pepeiborra/haskell-src-exts-util
synopsis:             Helper functions for working with haskell-src-exts trees
description:          Helper functions for working with haskell-src-exts trees.
category:             language
abi:                  fd02d9acccba91ea5071971fd48015f1
exposed:              True
exposed-modules:      Language.Haskell.Exts.Util
hidden-modules:
    Language.Haskell.Exts.Bracket Language.Haskell.Exts.FreeVars
    Language.Haskell.Exts.Util.Internal Paths_haskell_src_exts_util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/haskell-src-exts-util-0.2.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/haskell-src-exts-util-0.2.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/haskell-src-exts-util-0.2.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-src-exts-util
hs-libraries:         HShaskell-src-exts-util-0.2.5-52dyUv2dnwdFl4IOXeEnw9
depends:
    base-4.17.2.1 containers-0.6.7
    data-default-0.7.1.2-LONLsSvT4G81IL8ks6Ql72
    haskell-src-exts-1.23.1-8YCvwGoz5v65yIba8GoVHN transformers-0.5.6.2
    uniplate-1.6.13-DqW9yknleXtDZY0131RIUT

haddock-interfaces:
    /usr/share/doc/haskell-src-exts-util/html/haskell-src-exts-util.haddock

haddock-html:         /usr/share/doc/haskell-src-exts-util/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
